@@ -23,8 +23,7 @@ from qctrl.builders.type_registry import TypeOverrideMixin
 class ComplexNumberHandler(
     NamedObjectHandler, TypeOverrideMixin
 ):  # pylint:disable=too-many-ancestors
-    """Custom handler for ComplexNumber.
-    """
+    """Custom handler for ComplexNumber."""
 
     _type_hint = complex
     _object_name = "ComplexNumber"
