@@ -1,6 +1,16 @@
-"""
-Dynamically created classes.
-"""
+# Copyright 2020 Q-CTRL Pty Ltd & Q-CTRL Inc. All rights reserved.
+#
+# Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
+# copying or use of this file, via any medium, is strictly prohibited.
+# Proprietary and confidential. You may not use this file except in compliance
+# with the License. You may obtain a copy of the License at
+#
+#     https://q-ctrl.com/terms
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS. See the
+# License for the specific language.
+"""Dynamically created classes."""
 import inspect
 import sys
 from functools import wraps
