@@ -145,9 +145,12 @@ class Qctrl:
         retry=tenacity.retry_if_exception_type((RequestException, BaseHTTPError)),
     )
     def _build_namespaces(self):
-        """Builds the dynamic namespaces.
-        """
-        (self.functions, self.operations, self.types,) = build_namespaces(self)
+        """Builds the dynamic namespaces."""
+        (
+            self.functions,
+            self.operations,
+            self.types,
+        ) = build_namespaces(self)
 
     @staticmethod
     def create_graph():
